@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.47 2008/05/08 00:13:45 msk Exp $";
+static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.49 2008/07/22 20:42:38 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -17,6 +17,9 @@ static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.47 2008/05/08 00:13:4
 #include <limits.h>
 
 /* libsm includes */
+#include <sm/gen.h>
+#include <sm/types.h>
+#include <sm/cdefs.h>
 #include <sm/string.h>
 
 /* libdkim includes */
@@ -38,6 +41,79 @@ extern void dkim_error __P((DKIM *, const char *, ...));
 
 /* ========================= PRIVATE SECTION ========================= */
 
+/*
+**  DKIM_CANON_FREE -- destroy a canonicalization
+**
+**  Parameters:
+**  	dkim -- DKIM handle
+**  	canon -- canonicalization to destroy
+**
+**  Return value:
+**  	None.
+*/
+
+static void
+dkim_canon_free(DKIM *dkim, DKIM_CANON *canon)
+{
+	assert(dkim != NULL);
+	assert(canon != NULL);
+
+	if (canon->canon_hash != NULL)
+	{
+		switch (canon->canon_hashtype)
+		{
+		  case DKIM_HASHTYPE_SHA1:
+		  {
+			struct dkim_sha1 *sha1;
+
+			sha1 = (struct dkim_sha1 *) canon->canon_hash;
+
+			if (sha1->sha1_tmpbio != NULL)
+			{
+				BIO_free(sha1->sha1_tmpbio);
+				sha1->sha1_tmpfd = -1;
+				sha1->sha1_tmpbio = NULL;
+			}
+
+			break;
+		  }
+
+#ifdef DKIM_HASHTYPE_SHA256
+		  case DKIM_HASHTYPE_SHA256:
+		  {
+			struct dkim_sha256 *sha256;
+
+			sha256 = (struct dkim_sha256 *) canon->canon_hash;
+
+			if (sha256->sha256_tmpbio != NULL)
+			{
+				BIO_free(sha256->sha256_tmpbio);
+				sha256->sha256_tmpfd = -1;
+				sha256->sha256_tmpbio = NULL;
+			}
+
+			break;
+		  }
+#endif /* DKIM_HASHTYPE_SHA256 */
+
+		  default:
+			assert(0);
+			/* NOTREACHED */
+		}
+
+		dkim_mfree(dkim->dkim_libhandle, dkim->dkim_closure,
+		           canon->canon_hash);
+	}
+
+	if (canon->canon_hashbuf != NULL)
+	{
+		dkim_mfree(dkim->dkim_libhandle, dkim->dkim_closure,
+		           canon->canon_hashbuf);
+	}
+
+	dkim_mfree(dkim->dkim_libhandle, dkim->dkim_closure, canon);
+}
+
 /*
 **  DKIM_CANON_WRITE -- write data to canonicalization stream(s)
 **
@@ -1635,76 +1711,3 @@ dkim_canon_getfinal(DKIM_CANON *canon, u_char **digest, size_t *dlen)
 		return DKIM_STAT_INTERNAL;
 	}
 }
-
-/*
-**  DKIM_CANON_FREE -- destroy a canonicalization
-**
-**  Parameters:
-**  	dkim -- DKIM handle
-**  	canon -- canonicalization to destroy
-**
-**  Return value:
-**  	None.
-*/
-
-void
-dkim_canon_free(DKIM *dkim, DKIM_CANON *canon)
-{
-	assert(dkim != NULL);
-	assert(canon != NULL);
-
-	if (canon->canon_hash != NULL)
-	{
-		switch (canon->canon_hashtype)
-		{
-		  case DKIM_HASHTYPE_SHA1:
-		  {
-			struct dkim_sha1 *sha1;
-
-			sha1 = (struct dkim_sha1 *) canon->canon_hash;
-
-			if (sha1->sha1_tmpbio != NULL)
-			{
-				BIO_free(sha1->sha1_tmpbio);
-				sha1->sha1_tmpfd = -1;
-				sha1->sha1_tmpbio = NULL;
-			}
-
-			break;
-		  }
-
-#ifdef DKIM_HASHTYPE_SHA256
-		  case DKIM_HASHTYPE_SHA256:
-		  {
-			struct dkim_sha256 *sha256;
-
-			sha256 = (struct dkim_sha256 *) canon->canon_hash;
-
-			if (sha256->sha256_tmpbio != NULL)
-			{
-				BIO_free(sha256->sha256_tmpbio);
-				sha256->sha256_tmpfd = -1;
-				sha256->sha256_tmpbio = NULL;
-			}
-
-			break;
-		  }
-#endif /* DKIM_HASHTYPE_SHA256 */
-
-		  default:
-			assert(0);
-			/* NOTREACHED */
-		}
-
-		dkim_mfree(dkim->dkim_libhandle, dkim->dkim_closure,
-		           canon->canon_hash);
-	}
-
-	if (canon->canon_hashbuf != NULL)
-	{
-		dkim_mfree(dkim->dkim_libhandle, dkim->dkim_closure,
-		           canon->canon_hashbuf);
-	}
-
-	dkim_mfree(dkim->dkim_libhandle, dkim->dkim_closure, canon);
-}
