@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_tables_c_id[] = "@(#)$Id: dkim-tables.c,v 1.41 2008/05/19 23:57:40 msk Exp $";
+static char dkim_tables_c_id[] = "@(#)$Id: dkim-tables.c,v 1.42 2008/07/10 17:28:37 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -74,9 +74,6 @@ static struct nametable prv_policyresults[] =	/* policy results */
 	{ "none",				DKIM_PRESULT_NONE },
 	{ "author domain policy found",		DKIM_PRESULT_AUTHOR },
 	{ "domain does not exist",		DKIM_PRESULT_NXDOMAIN },
-	{ "parent domain policy found",		DKIM_PRESULT_PARENT },
-	{ "no parent domain policy found",	DKIM_PRESULT_NOPARENT },
-	{ "parent policy doesn't allow subdomains", DKIM_PRESULT_NOSUBDOMAIN },
 	{ NULL,					-1 }
 };
 struct nametable *policyresults = prv_policyresults;
