@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test12_c_id[] = "@(#)$Id: t-test12.c,v 1.9 2007/08/20 16:52:04 msk Exp $";
+static char t_test12_c_id[] = "@(#)$Id: t-test12.c,v 1.10 2008/07/22 20:51:17 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -13,6 +13,9 @@ static char t_test12_c_id[] = "@(#)$Id: t-test12.c,v 1.9 2007/08/20 16:52:04 msk
 #include <string.h>
 #include <stdio.h>
 
+/* libsm includes */
+#include <sm/gen.h>
+
 /* libdkim includes */
 #include "dkim.h"
 #include "t-testdata.h"
