@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test64_c_id[] = "@(#)$Id: t-test64.c,v 1.6 2007/09/17 16:36:45 msk Exp $";
+static char t_test64_c_id[] = "@(#)$Id: t-test64.c,v 1.7 2008/07/22 20:51:17 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -14,6 +14,9 @@ static char t_test64_c_id[] = "@(#)$Id: t-test64.c,v 1.6 2007/09/17 16:36:45 msk
 #include <stdio.h>
 #include <stdlib.h>
 
+/* libsm includes */
+#include <sm/gen.h>
+
 /* libdkim includes */
 #include "dkim.h"
 #include "t-testdata.h"
