@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test66_c_id[] = "@(#)$Id: t-test66.c,v 1.5 2007/10/26 23:48:55 msk Exp $";
+static char t_test66_c_id[] = "@(#)$Id: t-test66.c,v 1.6 2008/07/22 20:51:17 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -13,6 +13,9 @@ static char t_test66_c_id[] = "@(#)$Id: t-test66.c,v 1.5 2007/10/26 23:48:55 msk
 #include <string.h>
 #include <stdio.h>
 
+/* libsm includes */
+#include <sm/gen.h>
+
 /* libdkim includes */
 #include "dkim.h"
 #include "t-testdata.h"
